@@ -303,7 +303,7 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("kdf");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kdf"));
 
     KAboutData aboutData(QStringLiteral("kwikdisk"),
                      i18n("KwikDisk"),
@@ -349,3 +349,5 @@ int main(int argc, char **argv)
 /*****************************************************************************/
 
 
+
+#include "moc_kwikdisk.cpp"
